/*
 * OpenGL-like API for testing __thread variables in shared libraries.
 *
 * Gareth Hughes <gareth@nvidia.com>
 */

#ifndef __foo_internal_h_
#define __foo_internal_h_

#define FOO_COLOR       1

struct foo_context {
    float color[4];
    float position[4];
    unsigned int flags;
};

struct foo_dispatch {
    void (*Color3f)(float x, float y, float z);
    void (*Vertex3f)(float x, float y, float z);
};

typedef struct foo_context foo_context_t;
typedef struct foo_dispatch foo_dispatch_t;

/* Internal API entrypoint implementations */
extern void __foo_Color3f(float x, float y, float z);
extern void __foo_Vertex3f(float x, float y, float z);

/* Helper functions for OG code */
extern int __foo_get_context_offset(void);
extern int __foo_get_dispatch_offset(void);

/* The thread-local variables */
extern __thread foo_context_t *__foo_context __attribute__((tls_model("local-exec")));
extern __thread foo_dispatch_t *__foo_dispatch __attribute__((tls_model("local-exec")));

#endif /* __foo_internal_h_ */
